@@ -3,7 +3,7 @@
 from .client import RestClient
 from .openid_client import OpenIDRestClient
 from .client_credentials import ClientCredentialsAuth
-from .device_client import DeviceGrantAuth
+from .device_client import DeviceGrantAuth, SavedDeviceGrantAuth
 from .session import AsyncSession, Session
 
 __all__ = [
@@ -11,6 +11,7 @@ __all__ = [
     "OpenIDRestClient",
     "ClientCredentialsAuth",
     "DeviceGrantAuth",
+    "SavedDeviceGrantAuth",
     "AsyncSession",
     "Session",
 ]
